package members

import (
	base_ctl "SCRM/controllers"
	"SCRM/enums"
	"SCRM/service/member_service"
	"SCRM/utils"

	"github.com/astaxie/beego"
)

func MemberCtlRegistRouters() {
	beego.Router("/api/members", &MembersAPIController{}, "get:GetMembers")
}

type MembersAPIController struct {
	base_ctl.BaseAuthAPIController
}

func (c *MembersAPIController) GetMembers() {
	page, _ := c.GetInt64("page", 1)
	limit, _ := c.GetInt64("limit", 10)
	startTime := c.GetString("start_time", "")
	endTime := c.GetString("end_time", "")
	searchKey := c.GetString("search", "")
	level, _ := c.GetInt64("level", 0)
	source, _ := c.GetInt64("source", 0)
	tag, _ := c.GetInt64("tag", 0)
	init, _ := c.GetInt64("init", 0)

	if page <= 0 {
		page = 1
	}
	if limit <= 0 {
		limit = 10
	}

	adminUserInfo := c.GetAdminUserInfo()

	timeLayout := "2006-01-02 15:04:05"

	var isStartTime bool
	var theStartTIme int64
	if len(startTime) > 0 {
		theTime, err := utils.ParseTimeStringToTime(timeLayout, startTime+" 00:00:00")
		if err != nil {
			c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "开始时间错误")
			return
		}
		isStartTime = true
		theStartTIme = theTime.Unix()
	}
	var isEndTime bool
	var theEndtTIme int64
	if len(endTime) > 0 {
		theTime, err := utils.ParseTimeStringToTime(timeLayout, endTime+" 23:59:59")
		if err != nil {
			c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "结束时间错误")
			return
		}
		isEndTime = true
		theEndtTIme = theTime.Unix()
	}

	members, total, err := member_service.GetMemberList(adminUserInfo.CurrentOrgId, page, limit, level, source, tag, theStartTIme, theEndtTIme, isStartTime, isEndTime, searchKey)

	if err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDataException, "获取会员列表失败")
		return
	}

	returnData := make(map[string]interface{}, 0)
	if init == 1 {
		cards, err := member_service.GetCardList(adminUserInfo.CurrentOrgId)
		if err != nil {
			c.ServeFailJsonSend(enums.ErrorCodeDataException, "获取会员卡列表失败")
			return
		}
		returnData["cards"] = cards

		tags, err := member_service.GetTagList(adminUserInfo.CurrentOrgId)
		if err != nil {
			c.ServeFailJsonSend(enums.ErrorCodeDataException, "获取标签列表失败")
			return
		}
		returnData["tags"] = tags
	}
	returnData["members"] = members
	returnData["total"] = total

	c.ServeSuccessJSON(returnData)
	return
}
